@@ -12,7 +12,7 @@ from .devel import Devel
 from .fsmparser import FSMParser
 from .tocpageset import TocPageset
 from .tocpage import TocPage
-from .toccriteria import TocCriteria
+from .facet import Facet
 from .newscriteria import NewsCriteria
 from .transformer import Transformer
 from .document import Document
@@ -21,4 +21,6 @@ from .documentstore import DocumentStore
 from .documentrepository import DocumentRepository
 from .pdfdocumentrepository import PDFDocumentRepository
 from .compositerepository import CompositeRepository, CompositeStore
-__version__ = "0.1.7" #gets pulled into setup.py and docs/conf.py
+from .resources import Resources
+from .wsgiapp import WSGIApp
+__version__ = "0.2.0" #gets pulled into setup.py and docs/conf.py
