@@ -113,9 +113,9 @@ class Devel(object):
         predicates = ['basefile',
                       'subobjects', # sections that have rdf:type
                       'rdf:type',
-                      'dct:identifier',
-                      'dct:title',
-                      'dct:published',
+                      'dcterms:identifier',
+                      'dcterms:title',
+                      'dcterms:published',
                       'prov:wasGeneratedBy',
                       ]
         import csv
@@ -355,10 +355,16 @@ class Devel(object):
             # NO! res must be a bytestring, select should return
             # whatever is the appropriately encoded version for the
             # given format.
-            
             print(res.decode('utf-8'))
 
-
+    @decorators.action
+    def destroyindex(self):
+        f = FulltextIndex.connect(self.config.indextype,
+                                  self.config.indexlocation,
+                                  [])
+        f.destroy()
+        print("%s index at %s destroyed" % (self.config.indextype,
+                                            self.config.indexlocation))
 
     # FIXME: These are dummy implementations of methods and class
     # variables that manager.py expects all docrepos to have. We don't
