@@ -31,3 +31,6 @@ class Document(object):
         self.uri = uri
         self.lang = lang
         self.basefile = basefile
+
+    def __eq__(self, other):
+        return self.__dict__ == other.__dict__
