@@ -117,17 +117,13 @@ with.
 
         """
 
-        def mydefault(obj):
-            if isinstance(obj, datetime):
-                return obj.isoformat()
-            raise TypeError("%r is not JSON serializable" % obj)
 
         if not path:
             path = self._path  # better be there
         d = dict((k, v) for (k, v) in self.__dict__.items() if k[0] != "_")
         util.ensure_dir(path)
         with open(path, "w") as fp:
-            json.dump(d, fp, default=mydefault, indent=2, separators=(', ',': '), sort_keys=True)
+            json.dump(d, fp, default=util.json_default_date, indent=2, separators=(', ',': '), sort_keys=True)
     # If inline=True, the contents of filename is included in the Atom
     # entry. Otherwise, it just references it.
     #
