@@ -35,7 +35,7 @@ import pyparsing
 
 from ferenda import util
 
-DCT = Namespace(util.ns['dct'])
+DCTERMS = Namespace(util.ns['dcterms'])
 RDF = Namespace(util.ns['rdf'])
 XML_LANG = "{http://www.w3.org/XML/1998/namespace}lang"
 log = logging.getLogger(__name__)
@@ -235,23 +235,28 @@ class CompoundElement(AbstractElement, list):
         # create extra attributes depending on circumstances
         if hasattr(self,'uri') and self.uri:
             attrs['about'] = self.uri
-            
+
+        
         if hasattr(self,'uri') and self.uri and hasattr(self,'meta') and self.meta:
             assert isinstance(self.meta,Graph), "self.meta is %r, not rdflib.Graph" % type(self.meta)
             # we use sorted() to get the triples in a predictable
-            # order (by predicate)
-            for (s,p,o) in sorted(self.meta, key=itemgetter(1)):
+            # order (by predicate, then subject, then object)
+            for (s,p,o) in sorted(self.meta, key=itemgetter(1,0,2)):
                 if s != URIRef(self.uri):
                     continue
                 if p == RDF.type:
                     attrs['typeof'] = self.meta.qname(o)
-                    # attrs['rev'] = self.meta.qname(DCT.isPartOf)
-                elif p == DCT.title:
+                    # attrs['rev'] = self.meta.qname(DCTERMS.isPartOf)
+                elif p == DCTERMS.title:
                     attrs['property'] = self.meta.qname(p)
                     attrs['content'] = o.toPython()
                 else:
+                    # FIXME: Is it sane to reverse the order of
+                    # triples in this way? Maybe we should do a
+                    # children.append instead?
                     children.insert(0, self._span(s,p,o,self.meta))
 
+
         # for each childen that is a string, make sure it doesn't
         # contain any XML illegal characters
         return E(self.tagname, attrs, *children)
@@ -432,7 +437,7 @@ class Link(UnicodeElement):
 class LinkSubject(PredicateElement, Link):
     """A unicode string that has both ``predicate`` and ``uri``
     attributes, i.e. a typed link. Note that predicate should be a
-    string that represents a Qname, eg 'dct:references', not a proper
+    string that represents a Qname, eg 'dcterms:references', not a proper
     rdflib object.
 
     """
@@ -475,7 +480,7 @@ class SectionalElement(CompoundElement):
         # themselves.
         element = super(SectionalElement, self).as_xhtml(baseuri)
         if not hasattr(self, 'uri') or not hasattr(self, 'meta'):
-            element.set('property', 'dct:title')
+            element.set('property', 'dcterms:title')
             element.set('content', self.title)
             element.set('typeof', 'bibo:DocumentPart')
             element.set('about', newuri)
@@ -489,7 +494,7 @@ class SectionalElement(CompoundElement):
                 element.insert(0,E('span',attrs))
             if hasattr(self,'identifier'):
                 attrs = {'about': newuri,
-                         'property': 'dct:identifier',
+                         'property': 'dcterms:identifier',
                          'content': self.identifier}
                 element.insert(0,E('span',attrs))
             if element.text: # make sure that naked PCDATA comes after the elements we've inserted
