@@ -33,7 +33,7 @@ from ferenda.elements import Body, Paragraph, CompoundElement, OrdinalElement, H
 
 from ferenda.elements.html import Strong, Em
 from . import SwedishLegalSource, SwedishCitationParser, RPUBL
-DCT = Namespace(util.ns['dct'])
+DCTERMS = Namespace(util.ns['dcterms'])
 PROV = Namespace(util.ns['prov'])
 
 # Objektmodellen för rättsfall:
@@ -49,11 +49,11 @@ PROV = Namespace(util.ns['prov'])
 #     rpubl:sidnummer "695";
 #     rpubl:referatAvDomstolsavgorande <http://localhost:8000/res/dv/hd/t170-08/2009-11-04>;
 #     rpubl:referatrubrik "Överföring av mönsterregistrering..."@sv;
-#     dct:identifier "NJA 1987 s 187";
-#     dct:bibliographicCitation "NJA 1987:68"
+#     dcterms:identifier "NJA 1987 s 187";
+#     dcterms:bibliographicCitation "NJA 1987:68"
 # This shld b owl:sameAs <http://rinfo.lagrummet.se/org/domstolsverket>
-#     dct:publisher <http://localhost:8000/org/domstolsverket>;
-#     dct:issued "2009-11-05"^^xsd:date.
+#     dcterms:publisher <http://localhost:8000/org/domstolsverket>;
+#     dcterms:issued "2009-11-05"^^xsd:date.
 #
 #
 #  <http://localhost:8000/res/dv/hd/t170-08/2009-11-04> a VagledandeDomstolsavgorande;
@@ -67,16 +67,16 @@ PROV = Namespace(util.ns['prov'])
 # rpubl:lagrum <http://localhost:8000/res/sfs/1970:485#P5>;
 # rpubl:lagrum <http://localhost:8000/res/sfs/1970:485#P31>;
 # rpubl:lagrum <http://localhost:8000/res/sfs/1970:485#P32>;
-#     dct:title "Överföring av mönsterregistrering..."@sv;
+#     dcterms:title "Överföring av mönsterregistrering..."@sv;
 # shld be owl:sameAs <http://rinfo.lagrummet.se/org/hoegsta_domstolen>
-#     dct:publisher <http://localhost:8000/org/hoegsta_domstolen>;
-#     dct:issued "2009-11-05"^^xsd:date;
-#     dct:subject <http://localhost:8000/concept/Mönsterrätt>;
-#     dct:subject <http://localhost:8000/concept/Dubbelöverlåtelse>;
-#     dct:subject <http://localhost:8000/concept/Formgivarrätt>;
-#     dct:subject <http://localhost:8000/concept/Godtrosförvärv>;
-#     dct:subject <http://localhost:8000/concept/Formgivning>;
-# litteratur? dct:references t bnodes...
+#     dcterms:publisher <http://localhost:8000/org/hoegsta_domstolen>;
+#     dcterms:issued "2009-11-05"^^xsd:date;
+#     dcterms:subject <http://localhost:8000/concept/Mönsterrätt>;
+#     dcterms:subject <http://localhost:8000/concept/Dubbelöverlåtelse>;
+#     dcterms:subject <http://localhost:8000/concept/Formgivarrätt>;
+#     dcterms:subject <http://localhost:8000/concept/Godtrosförvärv>;
+#     dcterms:subject <http://localhost:8000/concept/Formgivning>;
+# litteratur? dcterms:references t bnodes...
 #
 # uri: http://localhost:8000/res/dv/nja/2009/s_695 # hard to construct from "HDO/T170-08", requires a rdf lookup like .value(pred=RDF.type, object=RPUBL.Rattsfallsreferat)
 # lang: sv
@@ -147,27 +147,27 @@ class DomElement(CompoundElement):
     def as_xhtml(self, baseuri):
         element = super(DomElement, self).as_xhtml(baseuri)
         if self.prop:
-            # ie if self.prop = ('ordinal', 'dct:identifier'), then
-            # dct:identifier = self.ordinal
+            # ie if self.prop = ('ordinal', 'dcterms:identifier'), then
+            # dcterms:identifier = self.ordinal
             if hasattr(self, self.prop[0]) and getattr(self, self.prop[0]):
                 element.set('content', getattr(self, self.prop[0]))
                 element.set('property', self.prop[1])
         return element
 
 class Delmal(DomElement):
-    prop = ('ordinal', 'dct:identifier')
+    prop = ('ordinal', 'dcterms:identifier')
     
 class Instans(DomElement):
-    prop = ('court', 'dct:creator')
+    prop = ('court', 'dcterms:creator')
         
 class Dom(DomElement):
-    prop = ('malnr', 'dct:identifier')
+    prop = ('malnr', 'dcterms:identifier')
     
 class Domskal(DomElement): pass 
-class Domslut(DomElement): pass # dct:author <- names of judges
-class Betankande(DomElement): pass # dct:author <- referent
-class Skiljaktig(DomElement): pass # dct:author <- name
-class Tillagg(DomElement): pass # dct:author <- name
+class Domslut(DomElement): pass # dcterms:author <- names of judges
+class Betankande(DomElement): pass # dcterms:author <- referent
+class Skiljaktig(DomElement): pass # dcterms:author <- name
+class Tillagg(DomElement): pass # dcterms:author <- name
 class Endmeta(DomElement): pass
         
 class DV(SwedishLegalSource):
@@ -177,25 +177,63 @@ class DV(SwedishLegalSource):
     documentstore_class = DVStore
     namespaces = ('rdf',  # always needed
                   'xsi',  # XML Schema/RDFa validation
-                  'dct',  # title, identifier, etc
+                  'dcterms',  # title, identifier, etc
                   'xsd',  # datatypes
                   'owl',  # : sameAs
                   'prov',
                   ('rpubl', 'http://rinfo.lagrummet.se/ns/2008/11/rinfo/publ#')
                   )
     # This is very similar to SwedishLegalSource.required_predicates,
-    # only DCT.title has been changed to RPUBL.referatrubrik (and if
+    # only DCTERMS.title has been changed to RPUBL.referatrubrik (and if
     # our validating function grokked that rpubl:referatrubrik
-    # rdfs:isSubpropertyOf dct:title, we wouldn't need this). Also, we
-    # removed dct:issued because there is no actual way of getting
+    # rdfs:isSubpropertyOf dcterms:title, we wouldn't need this). Also, we
+    # removed dcterms:issued because there is no actual way of getting
     # this data (apart from like the file time stamps).  On further
     # thinking, we remove RPUBL.referatrubrik as it's not present (or
     # required) for rpubl:Rattsfallsnotis
-    required_predicates = [RDF.type, DCT.identifier, PROV.wasGeneratedBy]
+    required_predicates = [RDF.type, DCTERMS.identifier, PROV.wasGeneratedBy]
     
-    DCT = Namespace(util.ns['dct'])
+    DCTERMS = Namespace(util.ns['dcterms'])
     sparql_annotations = "res/sparql/dv-annotations.rq"
 
+    @classmethod
+    def relate_all_setup(cls, config):
+        # FIXME: If this was an instancemethod, we could use
+        # self.store methods instead
+        parsed_dir = os.path.sep.join([config.datadir, 'dv', 'parsed'])
+        mapfile = os.path.sep.join(
+            [config.datadir, 'dv', 'generated', 'uri.map'])
+        if not util.outfile_is_newer(util.list_dirs(parsed_dir, ".xhtml"), mapfile):
+            re_xmlbase = re.compile('<head about="%(uri)sres/%(alias)s/([^"]+)"' %
+                                    {'uri': config.url,
+                                     'alias': cls.alias})
+            log = cls._setup_logger(cls.alias)
+            log.info("Creating uri.map file")
+            cnt = 0
+            util.robust_remove(mapfile + ".new")
+            util.ensure_dir(mapfile)
+            # FIXME: Not sure utf-8 is the correct codec for us -- it
+            # might be iso-8859-1 (it's to be used by mod_rewrite).
+            with codecs.open(mapfile+".new", "w", encoding="utf-8") as fp:
+                for f in util.list_dirs(parsed_dir, ".xhtml"):
+                    # get basefile from f in the simplest way
+                    basefile = f[len(parsed_dir)+1:-6]
+                    head = codecs.open(f, encoding='utf-8').read(1024)
+                    m = re_xmlbase.search(head)
+                    if m:
+                        fp.write("%s\t%s\n" % (m.group(1), basefile))
+                        cnt += 1
+                    else:
+                        log.warning("%s: Could not find valid head[@about] in %s" % (basefile, f))
+            util.robust_rename(mapfile + ".new", mapfile)
+            log.info("uri.map created, %s entries" % cnt)
+        else:
+            print("Not regenerating uri.map")
+            pass
+        return super(cls, DV).relate_all_setup(config)
+
+    # def relate(self, basefile, otherrepos): pass
+        
     def get_default_options(self):
         opts = super(DV, self).get_default_options()
         opts['ftpuser'] = None
@@ -236,6 +274,29 @@ class DV(SwedishLegalSource):
         doc.uri = None # can't know this yet
         return doc
 
+    # override DocumentRepository.basefile_from_uri to account for the
+    # fact that there is no 1:1 correspondance between basefiles and
+    # uris
+    def basefile_from_uri(self, uri):
+        prefix = self.config.url + "res/" + self.alias + "/"
+        if uri.startswith(prefix):
+            path = uri[len(prefix):]
+            if not hasattr(self, "_basefilemap"):
+                self._basefilemap = {}
+                mapfile = self.store.path("uri", "generated", ".map")
+                with codecs.open(mapfile, encoding="utf-8") as fp:
+                    for line in fp:
+                        uriseg, basefile = line.split("\t")
+                        self._basefilemap[uriseg] = basefile.strip()
+
+            if path in self._basefilemap:
+                return self._basefilemap[path]
+            else:
+                self.log.warning("%s: Could not find corresponding basefile" % uri)
+                return None
+        else:
+            pass # The URI didn't start with our expected prefix, it's not a Rattsfall URI
+            
     # FIXME: store.list_basefiles_for("parse") must be fixed to handle two
     # different suffixes. Maybe store.downloaded_path() as well, so that
     # it returns .docx if a .docx file indeed exists, and .doc otherwise.
@@ -531,7 +592,7 @@ class DV(SwedishLegalSource):
                     if filetype == "docx":
                         self._simplify_ooxml(self.store.intermediate_path(previous_basefile))
                 util.ensure_dir(self.store.intermediate_path(basefile))
-                fp = open(self.store.intermediate_path(basefile), "w")
+                fp = codecs.open(self.store.intermediate_path(basefile), "w", encoding="utf-8")
                 fp.write('<body%s>' % xmlns)
                 if filetype != "docx":
                     fp.write("\n")
@@ -554,13 +615,13 @@ class DV(SwedishLegalSource):
         return created, untouched
 
     re_delimSplit = re.compile("[;,] ?").split
-    labels = {'Rubrik': DCT.description,
-              'Domstol': DCT['creator'],  # konvertera till auktoritetspost
+    labels = {'Rubrik': DCTERMS.description,
+              'Domstol': DCTERMS['creator'],  # konvertera till auktoritetspost
               'Målnummer': RPUBL['malnummer'],
               'Domsnummer': RPUBL['domsnummer'],
               'Diarienummer': RPUBL['diarienummer'],
               'Avdelning': RPUBL['domstolsavdelning'],
-              'Referat': DCT['identifier'],
+              'Referat': DCTERMS['identifier'],
               'Avgörandedatum': RPUBL['avgorandedatum'],  # konvertera till xsd:date
               }
 
@@ -568,9 +629,9 @@ class DV(SwedishLegalSource):
     # Litteratur/sökord har ingen motsvarighet i RPUBL-vokabulären
     multilabels = {'Lagrum': RPUBL['lagrum'],
                    'Rättsfall': RPUBL['rattsfallshanvisning'],
-                   # dct:references vore bättre, men sådana ska inte ha literalvärden
-                   'Litteratur': DCT['relation'],
-                   'Sökord': DCT['subject']
+                   # dcterms:references vore bättre, men sådana ska inte ha literalvärden
+                   'Litteratur': DCTERMS['relation'],
+                   'Sökord': DCTERMS['subject']
                    }
 
     # Listan härledd från containers.n3/rattsfallsforteckningar.n3 i
@@ -1100,10 +1161,10 @@ class DV(SwedishLegalSource):
             if label == "Rubrik":
                 value = util.normalize_space(value)
                 refdesc.value(self.ns['rpubl'].referatrubrik, value, lang="sv")
-                domdesc.value(self.ns['dct'].title, value, lang="sv")
+                domdesc.value(self.ns['dcterms'].title, value, lang="sv")
 
             elif label == "Domstol":
-                domdesc.rel(self.ns['dct'].publisher, self.lookup_resource(value))
+                domdesc.rel(self.ns['dcterms'].publisher, self.lookup_resource(value))
             elif label == "Målnummer":
                 for v in value:
                     # FIXME: In these cases (multiple målnummer, which
@@ -1131,10 +1192,10 @@ class DV(SwedishLegalSource):
                             refdesc.rel(self.ns['rpubl'][pred], uri)
                         else:
                             refdesc.value(self.ns['rpubl'][pred], m.group(1))
-                refdesc.value(self.ns['dct'].identifier, value)
+                refdesc.value(self.ns['dcterms'].identifier, value)
 
             elif label == "_nja_ordinal":
-                refdesc.value(self.ns['dct'].bibliographicCitation,
+                refdesc.value(self.ns['dcterms'].bibliographicCitation,
                               value)
                 m = re.search(r'\d{4}(?:\:| nr | not )(\d+)', value)
                 if m:
@@ -1161,17 +1222,17 @@ class DV(SwedishLegalSource):
                                         localize_uri(node.uri))
             elif label == "Litteratur":
                 for i in value.split(";"):
-                    domdesc.value(self.ns['dct'].relation, util.normalize_space(i))
+                    domdesc.value(self.ns['dcterms'].relation, util.normalize_space(i))
             elif label == "Sökord":
                 for s in value:
-                    domdesc.rel(self.ns['dct'].subject, sokord_uri(s))
+                    domdesc.rel(self.ns['dcterms'].subject, sokord_uri(s))
 
         # 3. mint some owl:sameAs URIs
         refdesc.rel(self.ns['owl'].sameAs, self.sameas_uri(refuri))
         domdesc.rel(self.ns['owl'].sameAs, self.sameas_uri(domuri))
 
         # 4. Add some same-for-everyone properties
-        refdesc.rel(self.ns['dct'].publisher, self.lookup_resource('Domstolsverket'))
+        refdesc.rel(self.ns['dcterms'].publisher, self.lookup_resource('Domstolsverket'))
         if 'not' in head['Referat']:
             refdesc.rdftype(self.ns['rpubl'].Rattsfallsnotis)
         else:
@@ -1181,7 +1242,7 @@ class DV(SwedishLegalSource):
         refdesc.value(self.ns['prov'].wasGeneratedBy, self.qualified_class_name())
 # FIXME: implement this
 #        # 5. Create a meaningful identifier for the verdict itself (ie. "Göta hovrätts dom den 42 september 2340 i mål B 1234-42")
-#        domdesc.value(self.ns['dct'].identifier, dom_to_identifier(head["Domstol"],
+#        domdesc.value(self.ns['dcterms'].identifier, dom_to_identifier(head["Domstol"],
 #                                                                   head["_localid"],
 #                                                                   head["Avgörandedatum"])
 #
@@ -1212,9 +1273,11 @@ class DV(SwedishLegalSource):
         if self.config.parsebodyrefs:
             if not hasattr(self, 'ref_parser'):
                 self.ref_parser = LegalRef(LegalRef.RATTSFALL, LegalRef.LAGRUM, LegalRef.FORARBETEN)
-            citparser = SwedishCitationParser(self.ref_parser)
+            citparser = SwedishCitationParser(self.ref_parser, self.config.url)
             b = citparser.parse_recursive(b)
+            
 
+        
         # convert the unstructured list of Paragraphs to a
         # hierarchical tree of instances, domslut, domskäl, etc
         b = self.structure_body(b)
@@ -1486,37 +1549,11 @@ class DV(SwedishLegalSource):
         p.initial_constructor = make_body
         p.debug = os.environ.get('FERENDA_FSMDEBUG', False)
         return p.parse(paras)
-        
-    # FIXME: port to relate_all_setup / _teardown
-    def GenerateMapAll(self):
-        mapfile = os.path.sep.join(
-            [self.baseDir, 'dv', 'generated', 'uri.map'])
-        util.robust_remove(mapfile + ".new")
 
-        parsed_dir = os.path.sep.join([self.baseDir, 'dv', 'parsed'])
-        self._do_for_all(parsed_dir, '.xht2', self.GenerateMap)
-        util.robustRename(mapfile + ".new", mapfile)
-
-    def GenerateMap(self, basefile):
-        start = time()
-        infile = os.path.relpath(self._xmlFileName(basefile))
-        head = codecs.open(infile, encoding='utf-8').read(1024)
-        m = self.re_xmlbase(head)
-        if m:
-            uri = "http://rinfo.lagrummet.se/publ/rattsfall/%s" % m.group(1)
-            mapfile = self.store.path('generated', 'uri.map', '.new')
-            util.ensure_dir(mapfile)
-            f = codecs.open(mapfile, 'a', encoding='iso-8859-1')
-            f.write("%s\t%s\n" % (m.group(1), basefile))
-            f.close()
-            self.log.info("%s ok" % basefile)
-            return
-        else:
-            self.log.warning("could not find xml:base in %s" % infile)
 
     def _simplify_ooxml(self, filename, pretty_print=True):
         # simplify the horrendous mess that is OOXML through simplify-ooxml.xsl
-        with open(filename) as fp:
+        with open(filename, "rb") as fp:
             intree = etree.parse(fp)
         fp = pkg_resources.resource_stream('ferenda', "res/xsl/simplify-ooxml.xsl")
         transform = etree.XSLT(etree.parse(fp))
@@ -1524,7 +1561,7 @@ class DV(SwedishLegalSource):
         resulttree = transform(intree)
         with open(filename, "wb") as fp:
             fp.write(etree.tostring(resulttree, pretty_print=pretty_print, encoding="utf-8"))
-        
+
 
     def _merge_ooxml(self, soup):
         # this is a similar step to _simplify_ooxml, but merges w:p
