@@ -29,8 +29,8 @@ from . import RPUBL
 from . import SwedishLegalSource, SwedishLegalStore
 from .swedishlegalsource import offtryck_parser, offtryck_gluefunc
 
-class PropPolo(Regeringen):
-    alias = "proppolo"
+class PropRegeringen(Regeringen):
+    alias = "propregeringen"
     re_basefile_strict = re.compile(r'Prop. (\d{4}/\d{2,4}:\d+)')
     re_basefile_lax = re.compile(
         r'(?:Prop\.?|) ?(\d{4}/\d{2,4}:\d+)', re.IGNORECASE)
@@ -322,7 +322,7 @@ class PropTrips(Trips):
                 # How to represent that one XHTML doc was created from
                 # plaintext, and another from PDF? create a bnode
                 # representing the source prov:wasDerivedFrom and set its
-                # dct:format to correct mime type
+                # dcterms:format to correct mime type
 
             d.value(self.ns['prov'].wasGeneratedBy, self.qualified_class_name())
             self.infer_triples(d, doc.basefile)
@@ -352,7 +352,7 @@ class PropTrips(Trips):
                 continue
             elif not doc.body and p.strip().startswith("Titel:"):
                 describer.value(
-                    self.ns['dct'].title, util.normalize_space(p[7:]))
+                    self.ns['dcterms'].title, util.normalize_space(p[7:]))
             else:
                 doc.body.append(Preformatted([p]))
 
@@ -368,7 +368,7 @@ class PropositionerStore(CompositeStore, SwedishLegalStore):
     pass
 
 class Propositioner(CompositeRepository, SwedishLegalSource):
-    subrepos = PropPolo, PropTrips, PropRiksdagen
+    subrepos = PropRegeringen, PropTrips, PropRiksdagen
     alias = "prop"
     xslt_template = "paged.xsl"
     storage_policy = "dir"
