@@ -99,6 +99,7 @@ class Riksdagen(SwedishLegalSource):
                 done = True
 
     def download_single(self, basefile, url=None):
+        attachment = None
         if isinstance(basefile, tuple):
             basefile, attachment = basefile
         if attachment:
@@ -112,7 +113,7 @@ class Riksdagen(SwedishLegalSource):
                 return False
 
         xmlfile = self.store.downloaded_path(basefile)
-        if not (self.config.force or not os.path.exists(xmlfile)):
+        if not (self.config.refresh or not os.path.exists(xmlfile)):
             self.log.debug("%s already exists" % (xmlfile))
             return False
 
@@ -204,8 +205,8 @@ class Riksdagen(SwedishLegalSource):
         d.rdftype(self.rdf_type)
         d.value(self.ns['prov'].wasGeneratedBy, self.qualified_class_name())
         xsoup = BeautifulSoup(open(self.store.downloaded_path(doc.basefile)).read(), "xml")
-        d.value(self.ns['dct'].title, xsoup.dokument.titel.text, lang="sv")
-        d.value(self.ns['dct'].issued, util.strptime(xsoup.dokument.publicerad.text,
+        d.value(self.ns['dcterms'].title, xsoup.dokument.titel.text, lang="sv")
+        d.value(self.ns['dcterms'].issued, util.strptime(xsoup.dokument.publicerad.text,
                                                         "%Y-%m-%d %H:%M:%S").date())
         self.infer_triples(d, doc.basefile)
         return True
