@@ -13,7 +13,7 @@ from rdflib import URIRef, Graph, XSD
 from pyparsing import Word, CaselessLiteral, Optional, nums
 
 from ferenda import DocumentRepository
-from ferenda import TextReader, Describer, FSMParser, CitationParser, URIFormatter
+from ferenda import TextReader, Describer, FSMParser, CitationParser, URIFormatter, Facet
 from ferenda import util
 from ferenda.decorators import action, recordlastdownload, managedparsing, downloadmax
 from ferenda.elements import Body, Heading, Preformatted, Paragraph, UnorderedList, ListItem, Section, Subsection, Subsubsection, UnicodeElement, CompoundElement, Link, serialize
@@ -48,7 +48,7 @@ class PreambleSection(CompoundElement):
     # well.
     def as_xhtml(self, uri):
         element = super(PreambleSection, self).as_xhtml(uri)
-        element.set('property', 'dct:title')
+        element.set('property', 'dcterms:title')
         element.set('content', self.title)
         element.set('typeof', 'bibo:DocumentPart')
         self.__class__.counter += 1
@@ -65,16 +65,19 @@ class RFC(DocumentRepository):
     document_url_regex = "http://tools.ietf.org/rfc/rfc(?P<basefile>\w+).txt"
     downloaded_suffix = ".txt"
     namespaces = ('rdf',  # always needed
-                  'dct',  # title, identifier, etc (could be replaced by equiv bibo prop?)
+                  'dcterms',  # title, identifier, etc (could be replaced by equiv bibo prop?)
                   'bibo',  # Standard and DocumentPart classes, chapter prop
                   'xsd',  # datatypes
-                  'foaf',  # rfcs are foaf:Documents for now
                   'prov', # for :wasGeneratedBy
                   ('rfc', 'http://example.org/ontology/rfc/')  # custom (fake) ontology
                   )
     sparql_annotations = "res/sparql/rfc-annotations.rq"
     xslt_template = "res/xsl/rfc.xsl"
-    rdf_type = URIRef("http://example.org/ontology/rfc/RFC")
+    rdf_type = [URIRef("http://example.org/ontology/rfc/RFC"),
+                URIRef("http://example.org/ontology/rfc/BCP"),
+                URIRef("http://example.org/ontology/rfc/STD"),
+                URIRef("http://example.org/ontology/rfc/FYI")]
+                
     # NOTES:
     #
     # Like many large document collections that has existed for a long
@@ -470,19 +473,24 @@ class RFC(DocumentRepository):
             realid = doc.basefile
         doc.uri = self.canonical_uri(realid)
         desc = Describer(doc.meta, doc.uri)
-        desc.rdftype(self.ns['rfc'].RFC)
         desc.value(self.ns['prov'].wasGeneratedBy, self.qualified_class_name())
-        desc.value(self.ns['dct'].title, title, lang="en")
+        desc.value(self.ns['dcterms'].title, title, lang="en")
         self.parse_header(header, desc)
-        if not desc.getvalues(self.ns['dct'].identifier):
-            desc.value(self.ns['dct'].identifier, "RFC %s" % doc.basefile)
+        # parse_header might have set .rdftype, but if not:
+        try:
+            desc.getrdftype()
+        except KeyError:
+            desc.rdftype(self.ns['rfc'].RFC)
+
+        if not desc.getvalues(self.ns['dcterms'].identifier):
+            desc.value(self.ns['dcterms'].identifier, "RFC %s" % doc.basefile)
 
         doc.lang = "en"
 
         # process body - remove the temporary Pagebreak objects, after
         # having extracted the shortTitle found in them
         shorttitle = self.cleanup_body(doc.body)
-        if shorttitle and (desc.getvalue(self.ns['dct'].title) != shorttitle):
+        if shorttitle and (desc.getvalue(self.ns['dcterms'].title) != shorttitle):
             desc.value(self.ns['bibo'].shortTitle, shorttitle, lang="en")
 
         # process body - add good metadata
@@ -530,7 +538,16 @@ class RFC(DocumentRepository):
         left = [x.split("   ", 1)[0].strip() for x in lines]
         right = [x.split("   ", 1)[1].strip() for x in lines if "   " in x]
         # first line of lefthand side is publishing organization (?)
-        desc.value(self.ns['dct'].publisher, left[0])
+        publisher_label = left[0]
+        try:
+            desc.rel(self.ns['dcterms'].publisher,
+                       self.lookup_resource(publisher_label))
+        except KeyError:
+            self.log.warn("Couldn't look up a proper resource URI for %s" %
+                          publisher_label)
+            desc.value(self.ns['dcterms'].publisher,
+                       publisher_label)
+            
         # following lefthand side are key-value headers
         for line in left[1:]:
             if line.strip() == "":
@@ -547,11 +564,17 @@ class RFC(DocumentRepository):
                 # variants
                 value = re.sub("\D", "", value)
                 if value:  # eg RFC 100
-                    desc.value(self.ns['dct'].identifier, "RFC %s" % value)
+                    desc.value(self.ns['dcterms'].identifier, "RFC %s" % value)
             elif key == "Category":
-                desc.value(self.ns['dct'].subject, value)
+                try:
+                    desc.rel(self.ns['dcterms'].subject,
+                               self.lookup_resource(value, predicate=self.ns['bibo'].identifier))
+                except KeyError:
+                    self.log.warn("Couldn't look up a proper resource URI for %s" %
+                                  value)
+                    desc.value(self.ns['dcterms'].subject, value)
             elif key == "ISSN":
-                desc.value(self.ns['dct'].issn, value)
+                desc.value(self.ns['dcterms'].issn, value)
             elif key in ("Updates", "Obsoletes"):
                 pred = {'Updates': self.ns['rfc'].updates,
                         'Obsoletes': self.ns['rfc'].obsoletes}[key]
@@ -564,11 +587,14 @@ class RFC(DocumentRepository):
                     else:
                         self.log.warning("Can't pick out RFC number from line %s" % line)
             elif key == "BCP":
-                desc.value(self.ns['rfc'].BCP, value)
+                desc.value(self.ns['rfc'].bcpnumber, value)
+                desc.rdftype(self.ns['rfc'].BCP)
             elif key == "STD":
-                desc.value(self.ns['rfc'].STD, value)
+                desc.value(self.ns['rfc'].stdnumber, value)
+                desc.rdftype(self.ns['rfc'].FYI)
             elif key == "FYI":
-                desc.value(self.ns['rfc'].FYI, value)
+                desc.value(self.ns['rfc'].fyinumber, value)
+                desc.rdftype(self.ns['rfc'].FYI)
             else:
                 # Unknown headers seen: BCP, STD, FYI
                 self.log.warning("Unknown header key %s (value %s)" % (key, value))
@@ -577,7 +603,7 @@ class RFC(DocumentRepository):
         # followed by '. ' is probably a name
         for line in right:
             if re.match("[A-Z]\. ", line):
-                desc.value(self.ns['dct'].creator, line)
+                desc.value(self.ns['dcterms'].creator, line)
             elif re.match("\w+ \d{4}$", line):
                 # NOTE: this requires english locale!
                 with util.c_locale():
@@ -586,56 +612,36 @@ class RFC(DocumentRepository):
                     # the date information. Use xsd:gYearMonth.
                     dt = datetime.strptime(line, "%B %Y")
                 d = util.gYearMonth(dt.year, dt.month)
-                desc.value(self.ns['dct'].issued, str(d),
+                desc.value(self.ns['dcterms'].issued, str(d),
                            datatype=XSD.gYearMonth)
             else:
                 # company affiliation - include that separate from
                 # personal author identity
-                desc.value(self.ns['dct'].rightsHolder, line)
+                desc.value(self.ns['dcterms'].rightsHolder, line)
 
-    def toc_predicates(self):
-        return [self.ns['dct'].identifier,
-                self.ns['dct'].title,
-                self.ns['dct'].issued,
-                self.ns['dct'].subject]
-
-    def toc_criteria(self, predicates=None):
-        from ferenda import TocCriteria
-
-        return [TocCriteria(binding='identifier',
-                            label='Sorted by RFC #',
-                            pagetitle='RFCs %(select)s--99',
-                            selector=lambda x: x['identifier'][4:-2] + "00",  # "RFC 6998" => "69"
-                            key=lambda x: int(x['identifier'][4:]),
-                            selector_descending=True,
-                            key_descending=True),   # "RFC 6998" => 6998
-
-                TocCriteria(binding='title',
-                            label='Sorted by title',
-                            pagetitle='Documents starting with "%(select)s"',
-                            # "The 'view-state'" property => "v"
-                            selector=lambda x: util.title_sortkey(x['title'])[0],
-                            key=lambda x: util.title_sortkey(x['title'])),
-
-                TocCriteria(binding='issued',
-                            label='Sorted by year',
-                            pagetitle='Documents published in %(select)s',
-                            selector=lambda x: x['issued'][:4],  # '2013-08-01' => '2013'
-                            key=lambda x: x['issued'],
-                            selector_descending=True,
-                            key_descending=True),
-
-                TocCriteria(binding='subject',
-                            label='Sorted by category',
-                            pagetitle='Documents in the %(select)s category',
-                            selector=lambda x: x['subject'],
-                            key=lambda x: int(x['identifier'][4:]),
-                            key_descending=True
-                            )]
+    def facets(self):
+        def select_rfcnum(row, binding, resource_graph):
+            # "RFC 6998" -> "6900"
+            return row[binding][4:-2] + "00"
+            
+        return [Facet(self.ns['rdf'].type),
+                Facet(self.ns['dcterms'].identifier,
+                      label="Sorted by RFC #",
+                      pagetitle="RFC %(selected)s00-%(selected)s99",
+                      selector=select_rfcnum,
+                      use_for_toc=True),
+                Facet(self.ns['dcterms'].title),
+                Facet(self.ns['dcterms'].publisher,
+                      label="Sorted by stream",
+                      pagetitle="The %(selected)s stream"),
+                Facet(self.ns['dcterms'].issued),
+                Facet(self.ns['dcterms'].subject,  # should be rfc:category not dcterms:status?
+                      label="Sorted by status",
+                      pagetitle="Status: %(selected)s")]
 
     def toc_item(self, binding, row):
-        return [row['identifier'] + ": ",
-                Link(row['title'],
+        return [row['dcterms_identifier'] + ": ",
+                Link(row['dcterms_title'],
                      uri=row['uri'])]
 
     def news_criteria(self):
@@ -649,18 +655,22 @@ class RFC(DocumentRepository):
                 with self.store.open_distilled(entry.basefile) as fp:
                     graph.parse(data=fp.read())
                 desc = Describer(graph, entry.id)
-                return desc.getvalue(self.ns['dct'].subject) == category
+                return desc.getrel(self.ns['dcterms'].subject) == category
             return selector
 
         return [NewsCriteria('all', 'All RFCs'),
                 NewsCriteria('informational', 'Informational RFCs',
-                             selector=selector_for("Informational")),
+                             selector=selector_for("http://localhost:8000/dataset/rfc/informational")),
                 NewsCriteria('bcp', 'Best Current Practice RFCs',
-                             selector=selector_for("Best Current Practice")),
+                             selector=selector_for("http://localhost:8000/dataset/rfc/best-current-practice")),
                 NewsCriteria('experimental', 'Experimental RFCs',
-                             selector=selector_for("Experimental")),
+                             selector=selector_for("http://localhost:8000/dataset/rfc/experimental")),
+                NewsCriteria('historic', 'Historic RFCs',
+                             selector=selector_for("http://localhost:8000/dataset/rfc/historic")),
+                NewsCriteria('unknown', 'Unknown',
+                             selector=selector_for("http://localhost:8000/dataset/rfc/unknown")),
                 NewsCriteria('standards', 'Standards Track RFCs',
-                             selector=selector_for("Standards Track"))]
+                             selector=selector_for("http://localhost:8000/dataset/rfc/standard"))]
 
     def frontpage_content(self, primary=False):
         from rdflib import URIRef
@@ -671,7 +681,7 @@ class RFC(DocumentRepository):
                 graph.parse(data=fp.read())
 
             data = {
-                'identifier': graph.value(URIRef(entry.id), self.ns['dct'].identifier).toPython(),
+                'identifier': graph.value(URIRef(entry.id), self.ns['dcterms'].identifier).toPython(),
                 'uri': entry.id,
                 'title': entry.title}
             items += '<li>%(identifier)s <a href="%(uri)s">%(title)s</a></li>' % data
