@@ -66,7 +66,7 @@ class gYear(datetime.date):
 # util.Namespaces
 # Set up common namespaces and suitable prefixes for them
 ns = {'dc': 'http://purl.org/dc/elements/1.1/',
-      'dct': 'http://purl.org/dc/terms/',
+      'dcterms': 'http://purl.org/dc/terms/',
       'rdfs': 'http://www.w3.org/2000/01/rdf-schema#',
       'rdf': 'http://www.w3.org/1999/02/22-rdf-syntax-ns#',
       'xsi': 'http://www.w3.org/2001/XMLSchema-instance',
@@ -75,10 +75,11 @@ ns = {'dc': 'http://purl.org/dc/elements/1.1/',
       'foaf': 'http://xmlns.com/foaf/0.1/',
       'owl': 'http://www.w3.org/2002/07/owl#',
       'xhv': 'http://www.w3.org/1999/xhtml/vocab#',
-      'prov': 'http://www.w3.org/ns/prov-o/',
+      'prov': 'http://www.w3.org/ns/prov#',
       'bibo': 'http://purl.org/ontology/bibo/',
+      'schema': 'http://schema.org/',
       }
-"""A mapping of well-known prefixes and their corresponding namespaces. Includes ``dc``, ``dct``, ``rdfs``, ``rdf``, ``skos``, ``xsd``, ``foaf``, ``owl``, ``xhv``, ``prov`` and ``bibo``."""
+"""A mapping of well-known prefixes and their corresponding namespaces. Includes ``dc``, ``dcterms``, ``rdfs``, ``rdf``, ``skos``, ``xsd``, ``foaf``, ``owl``, ``xhv``, ``prov`` and ``bibo``."""
 
 # util.File
 
@@ -280,31 +281,7 @@ def list_dirs(d, suffix=None, reverse=False):
                 else:
                     yield f
 
-# util.String (or XML?)
-# Still used by manager.makeresources, should be removed in favor of lxml
-#
-def indent_node(elem, level=0):
-    """indents a etree node, recursively.
-
-    .. note::
-
-       This is deprecated, don't use it
-    """
-    i = "\r\n" + level * "  "
-    if len(elem):
-        if not elem.text or not elem.text.strip():
-            elem.text = i + "  "
-        for elem in elem:
-            indent_node(elem, level + 1)
-        if not elem.tail or not elem.tail.strip():
-            elem.tail = i
-    else:
-        if level and (not elem.tail or not elem.tail.strip()):
-            elem.tail = i
-
 # util.File
-
-
 def replace_if_different(src, dst, archivefile=None):
     """Like :py:func:`shutil.move`, except the *src* file isn't moved if the
     *dst* file already exists and is identical to *src*. Also doesn't
@@ -444,6 +421,7 @@ HTTP-date) to an UTC-localized (naive) datetime.
     return (datetime.datetime(*parsed_date[:7]) -
             datetime.timedelta(seconds=parsed_date[9]))
 
+
 def strptime(datestr, format):
     """Like datetime.strptime, but guaranteed to not be affected by
     current system locale -- all datetime parsing is done using the C
@@ -704,3 +682,8 @@ def parseresults_as_xml(parseres, depth=0):
         # have any 3-level grammar productions to test with
         
     return "%s<%s>%s</%s>\n" % ("  "*depth, parseres.getName(), res, parseres.getName())
+
+def json_default_date(obj):
+    if isinstance(obj, (datetime.datetime, datetime.date)):
+        return obj.isoformat()
+    raise TypeError("%r is not JSON serializable" % obj)
