@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
+import json
+import logging
 import os
+import pkg_resources
+import shutil
 import sys
 import tempfile
-import shutil
-import logging
-import pkg_resources
-
 
 # NOTE: by inserting cwd (which *should* be the top-level source code
 # dir, with 'ferenda' and 'test' as subdirs) into sys.path as early as
@@ -40,6 +40,8 @@ class staticmockclass(DocumentRepository):
     alias = "staticmock"
     resourcebase = None
     documentstore_class = staticmockstore
+    namespaces = ('foaf', 'rdfs', 'rdf', 'owl', 'skos')
+    
     @decorators.action
     def mymethod(self, arg):
         """Frobnicate the bizbaz"""
@@ -78,6 +80,7 @@ class staticmockclass(DocumentRepository):
         opts.update({'datadir': 'data',
                      'loglevel': 'DEBUG',
                      'cssfiles': [self.resourcebase + '/test.css'],
+                     'imgfiles': [self.resourcebase + '/test.png'],
                      'jsfiles': [self.resourcebase + '/test.js']})
         return opts
                     
@@ -126,6 +129,7 @@ class=testManager.staticmockclass2
 """%self.tempdir)
         util.writefile(self.tempdir+"/test.js", "// test.js code goes here")
         util.writefile(self.tempdir+"/test.css", "/* test.css code goes here */")
+        util.writefile(self.tempdir+"/test.png", "\x89\x50\x4e\x47\x0d\x0a\x1a\x0a PNG data goes here")
         util.writefile(self.tempdir+"/transformed.scss", "a { color: red + green; }")
 
     def tearDown(self):
@@ -172,156 +176,6 @@ class=testManager.staticmockclass2
                          {'mymethod':'Frobnicate the bizbaz'})
 
 
-    def test_makeresources(self):
-        # Test1: No combining, resources specified by docrepos
-        test = staticmockclass()
-        # print("test.get_default_options %r" % test.get_default_options())
-        test2 = staticmockclass2()
-        s = os.sep
-        want = {'css':[s.join(['rsrc', 'css','test.css'])],
-                'js':[s.join(['rsrc', 'js','test.js'])],
-                'xml':[s.join(['rsrc', 'resources.xml'])]
-        }
-        got = manager.makeresources([test,test2],self.tempdir+os.sep+'rsrc')
-        self.assertEqual(want, got)
-        tree = ET.parse(self.tempdir+os.sep+got['xml'][0])
-        stylesheets=tree.find("stylesheets").getchildren()
-        self.assertEqual(len(stylesheets),1)
-        self.assertEqual(stylesheets[0].attrib['href'],'rsrc/css/test.css')
-        javascripts=tree.find("javascripts").getchildren()
-        self.assertEqual(len(javascripts),1)
-        self.assertEqual(javascripts[0].attrib['src'],'rsrc/js/test.js')
-        self.assertEqual(tree.find("sitename").text,"MySite")
-        self.assertEqual(tree.find("sitedescription").text,"Just another Ferenda site")
-        self.assertEqual(tree.find("url").text,"http://localhost:8000/")
-        self.assertTrue(os.path.exists(self.tempdir+'/rsrc/css/test.css'))
-        self.assertTrue(os.path.exists(self.tempdir+'/rsrc/js/test.js'))
-        tabs=tree.find("tabs")
-        self.assertTrue(tabs is not None)
-        search=tree.find("search")
-        self.assertTrue(search is not None)
-
-        # Test2: combining, resources specified by global config
-        # (maybe we should use smaller CSS+JS files? Test takes 2+ seconds...)
-        want = {'css':[s.join(['rsrc', 'css','combined.css'])],
-                'js':[s.join(['rsrc', 'js','combined.js'])],
-                'xml':[s.join(['rsrc', 'resources.xml'])]
-        }
-        got = manager.makeresources([test,test2],self.tempdir+os.sep+'rsrc',
-                                    combine=True,
-                                    cssfiles=['res/css/normalize-1.1.3.css',
-                                              'res/css/main.css'],
-                                    jsfiles=['res/js/jquery-1.10.2.js',
-                                             'res/js/modernizr-2.6.3.js',
-                                             'res/js/respond-1.3.0.js'],
-                                    sitename="Blahonga",
-                                    sitedescription="A non-default value")
-        self.assertEqual(want,got)
-        tree = ET.parse(self.tempdir+'/'+got['xml'][0])
-        stylesheets=tree.find("stylesheets").getchildren()
-        self.assertEqual(len(stylesheets),1)
-        self.assertEqual(stylesheets[0].attrib['href'],'rsrc/css/combined.css')
-        javascripts=tree.find("javascripts").getchildren()
-        self.assertEqual(len(javascripts),1)
-        self.assertEqual(javascripts[0].attrib['src'],'rsrc/js/combined.js')
-        self.assertEqual(tree.find("sitename").text,"Blahonga")
-        self.assertEqual(tree.find("sitedescription").text,"A non-default value")
-        self.assertTrue(os.path.exists(self.tempdir+'/rsrc/css/combined.css'))
-        self.assertTrue(os.path.exists(self.tempdir+'/rsrc/js/combined.js'))
-        # check that the combining/minifying indeed saved us some space
-        # physical path for these: relative to the location of ferenda/manager.py.
-        self.assertLess(os.path.getsize(self.tempdir+'/rsrc/css/combined.css'),
-                        sum([os.path.getsize(x) for x in ("ferenda/res/css/normalize-1.1.3.css",
-                                                          "ferenda/res/css/main.css")]))
-        self.assertLess(os.path.getsize(self.tempdir+'/rsrc/js/combined.js'),
-                        sum([os.path.getsize(x) for x in ("ferenda/res/js/jquery-1.10.2.js",
-                                                          "ferenda/res/js/modernizr-2.6.3.js",
-                                                          "ferenda/res/js/respond-1.3.0.js")]))
-        # Test3: No combining, make sure that a non-customized
-        # DocumentRepository works
-        repo = DocumentRepository()
-        # but remove any external urls -- that's tested separately in Test5
-        repo.config.cssfiles = [x for x in repo.config.cssfiles if not x.startswith("http://")]
-        got = manager.makeresources([repo],self.tempdir+os.sep+'rsrc')
-        s = os.sep
-        want = {'css':[s.join(['rsrc', 'css','normalize-1.1.3.css']),
-                       s.join(['rsrc', 'css','main.css']),
-                       s.join(['rsrc', 'css','ferenda.css'])],
-                'js':[s.join(['rsrc', 'js','jquery-1.10.2.js']),
-                      s.join(['rsrc', 'js','modernizr-2.6.3.js']),
-                      s.join(['rsrc', 'js','respond-1.3.0.js']),
-                      s.join(['rsrc', 'js','ferenda.js'])],
-                'xml':[s.join(['rsrc', 'resources.xml'])]
-                      }
-        self.assertEqual(want,got)
-
-        # test4: Make sure staticsite works (ie no search form in resources.xml):
-        repo = DocumentRepository()
-        got = manager.makeresources([repo],self.tempdir+os.sep+'rsrc', staticsite = True)
-        tree = ET.parse(self.tempdir+os.sep+got['xml'][0])
-        search=tree.find("search")
-        self.assertFalse(search)
-
-        # test5: include one external resource, combine=False
-        test = staticmockclass()
-        test.config.cssfiles.append('http://example.org/css/main.css')
-        want = {'css':[s.join(['rsrc', 'css','test.css']),
-                       'http://example.org/css/main.css'],
-                'js':[s.join(['rsrc', 'js','test.js'])],
-                'xml':[s.join(['rsrc', 'resources.xml'])]
-        }
-        got = manager.makeresources([test],self.tempdir+os.sep+'rsrc')
-        self.assertEqual(want,got)
-                                    
-        # test6: include one external resource but with combine=True, which is unsupported
-        with self.assertRaises(errors.ConfigurationError):
-            got = manager.makeresources([test],self.tempdir+os.sep+'rsrc', combine=True)
-
-        # test7: test the footer() functionality
-        test = staticmockclass3()
-        got = manager.makeresources([test], self.tempdir+os.sep+'rsrc')
-        tree = ET.parse(self.tempdir+os.sep+got['xml'][0])
-        footerlinks=tree.findall("footerlinks/nav/ul/li")
-        self.assertTrue(footerlinks)
-        self.assertEqual(3,len(footerlinks))
-
-        # test8: test win32 path generation on all OS:es, including one full URL
-        test = staticmockclass()
-        test.config.cssfiles.append('http://example.org/css/main.css')
-        want = {'css':['rsrc\\css\\test.css',
-                       'http://example.org/css/main.css'],
-                'js':['rsrc\\js\\test.js'],
-                'xml':['rsrc\\resources.xml']}
-        try:
-            realsep = os.sep
-            os.sep = "\\"
-            got = manager.makeresources([test], self.tempdir+os.sep+'rsrc')
-            self.assertEqual(want,got)
-        finally:
-            os.sep = realsep
-            
-        # test9: nonexistent resources should not be included
-        test = staticmockclass()
-        test.config.cssfiles = ['nonexistent.css']
-        want = {'css':[],
-                'js':[s.join(['rsrc', 'js','test.js'])],
-                'xml':[s.join(['rsrc', 'resources.xml'])]
-        }
-        got = manager.makeresources([test], self.tempdir+os.sep+'rsrc')
-        self.assertEqual(want,got)
-        
-        # test10: scss files should be transformed to css
-        # disabled until pyScss is usable on py3 again
-        # test = staticmockclass()
-        # test.config.cssfiles[0] = test.config.cssfiles[0].replace("test.css", "transformed.scss")
-        # want = {'css':[s.join(['rsrc', 'css','transformed.css'])],
-        #        'js':[s.join(['rsrc', 'js','test.js'])],
-        #        'xml':[s.join(['rsrc', 'resources.xml'])]
-        # }
-        # got = manager.makeresources([test], self.tempdir+os.sep+'rsrc')
-        # self.assertEqual(want,got)
-
-
     def test_frontpage(self):
         test = staticmockclass()
         test2 = staticmockclass2()
@@ -523,22 +377,33 @@ class Run(unittest.TestCase):
 
     def setUp(self):
         self.addTypeEqualityFunc(OrderedDict, self.assertDictEqual)
-        self.tempdir = tempfile.mkdtemp()
         # self.modulename = hashlib.md5(self.tempdir.encode('ascii')).hexdigest()
         self.modulename = "example"
-        self.orig_cwd = os.getcwd()
+        # When testing locally , we want to avoid cluttering cwd, so
+        # we chdir to a temp dir, but when testing on travis-ci,
+        # changing the wd makes subsequent calls to
+        # pkg_resources.resource_listdir fail (at least for python <=
+        # 3.2). Don't know why not the same thing happens locally.
+        if 'TRAVIS' in os.environ:
+            self.tempdir = os.getcwd()
+        else:
+            self.tempdir = tempfile.mkdtemp()
+            self.orig_cwd = os.getcwd()
+            os.chdir(self.tempdir)
         # 1. create new blank ini file (FIXME: can't we make sure that
         # _find_config_file is called with create=True when using
         # run() ?)
-        os.chdir(self.tempdir)
         util.writefile("ferenda.ini", """[__root__]
 loglevel=WARNING
 datadir = %s
-url = http://localhost:8000
+url = http://localhost:8000/
 searchendpoint = /search/
 apiendpoint = /api/
 cssfiles = ['test.css', 'other.css']        
 jsfiles = ['test.js']
+imgfiles = ['test.png']
+indextype = WHOOSH
+indexlocation = data/whooshindex        
         """ % self.tempdir)
 
         # 2. dump 2 example docrepo classes to example.py
@@ -553,12 +418,14 @@ class Teststore(DocumentStore):
 class Testrepo(DocumentRepository):
     alias = "test"
     documentstore_class = Teststore
+    namespaces = ('foaf', 'rdfs', 'rdf', 'owl', 'skos')
         
     def get_default_options(self):
         opts = super(Testrepo, self).get_default_options()
         opts.update({'datadir': 'data',
                      'cssfiles': ['test.css'],
                      'jsfiles': ['test.js'],
+                     'imgfiles': ['test.png'],
                      'magic': 'less'})
         return opts
 
@@ -639,13 +506,17 @@ class Testrepo2(Testrepo):
         util.writefile(self.tempdir+"/test.js", "// test.js code goes here")
         util.writefile(self.tempdir+"/test.css", "/* test.css code goes here */")
         util.writefile(self.tempdir+"/other.css", "/* other.css code goes here */")
+        util.writefile(self.tempdir+"/test.png", "\x89\x50\x4e\x47\x0d\x0a\x1a\x0a PNG data goes here")
         sys.path.append(self.tempdir)
 
     def tearDown(self):
         manager.shutdown_logger()
-        os.chdir(self.orig_cwd)
-        shutil.rmtree(self.tempdir)
-        sys.path.remove(self.tempdir)
+        if 'TRAVIS' in os.environ:
+            util.robust_remove("ferenda.ini")
+        else:
+            os.chdir(self.orig_cwd)
+            shutil.rmtree(self.tempdir)
+            sys.path.remove(self.tempdir)
 
 
     def test_noconfig(self):
@@ -765,8 +636,8 @@ class Testrepo2(Testrepo):
     # OSError: [Errno 2] No such file or directory: 'ferenda/res/xsl'
     #
     # I can not figure out why. Skip for now.
-    @unittest.skipIf('TRAVIS' in os.environ,
-                 "Skipping test_run_all_allmethods on travis-ci")    
+#    @unittest.skipIf('TRAVIS' in os.environ,
+#                 "Skipping test_run_all_allmethods on travis-ci")    
     def test_run_all_allmethods(self):
         self._enable_repos()
         argv = ["all", "all", "--magic=more"]
@@ -789,6 +660,10 @@ class Testrepo2(Testrepo):
              ('makeresources', {'css':[s.join(['rsrc', 'css','test.css']),
                                        s.join(['rsrc', 'css','other.css'])],
                                 'js':[s.join(['rsrc', 'js','test.js'])],
+                                'img':[s.join(['rsrc', 'img','test.png'])],
+                                'json': [s.join(['rsrc','api','context.json']),
+                                         s.join(['rsrc','api','common.json']),
+                                         s.join(['rsrc','api','terms.json'])],
                                 'xml':[s.join(['rsrc', 'resources.xml'])]}),
              ('generate', OrderedDict([('test', ['test generate arg1',
                                                  'test generate myarg',
@@ -807,8 +682,8 @@ class Testrepo2(Testrepo):
         
     # since this method also calls frontpage, it fails on travis in
     # the same way as test_run_all_allmethods.
-    @unittest.skipIf('TRAVIS' in os.environ,
-                 "Skipping test_run_single_allmethods on travis-ci")    
+#    @unittest.skipIf('TRAVIS' in os.environ,
+#                 "Skipping test_run_single_allmethods on travis-ci")    
     def test_run_single_allmethods(self):
         self._enable_repos()
         argv = ["test","all"]
@@ -827,7 +702,11 @@ class Testrepo2(Testrepo):
                                  ])),
              ('makeresources', {'css':[s.join(['rsrc', 'css','test.css']),
                                        s.join(['rsrc', 'css','other.css'])],
+                                'img':[s.join(['rsrc', 'img','test.png'])],
                                 'js':[s.join(['rsrc', 'js','test.js'])],
+                                'json': [s.join(['rsrc','api','context.json']),
+                                         s.join(['rsrc','api','common.json']),
+                                         s.join(['rsrc','api','terms.json'])],
                                 'xml':[s.join(['rsrc', 'resources.xml'])]}),
              ('generate', OrderedDict([('test', ['test generate arg1',
                                                  'test generate myarg',
@@ -854,6 +733,10 @@ class Testrepo2(Testrepo):
         want = {'css':[s.join(['rsrc', 'css','test.css']),
                        s.join(['rsrc', 'css','other.css'])],
                 'js':[s.join(['rsrc', 'js','test.js'])],
+                'img': [s.join(['rsrc', 'img', 'test.png'])],
+                'json': [s.join(['rsrc','api','context.json']),
+                         s.join(['rsrc','api','common.json']),
+                         s.join(['rsrc','api','terms.json'])],
                 'xml':[s.join(['rsrc', 'resources.xml'])]
         }
         got = manager.run(['all', 'makeresources'])
@@ -863,12 +746,16 @@ class Testrepo2(Testrepo):
         util.writefile("ferenda.ini", """[__root__]
 loglevel=WARNING
 datadir = %s
-url = http://localhost:8000
+url = http://localhost:8000/
 searchendpoint = /search/
 apiendpoint = /api/
         """ % self.tempdir)
         want = {'css':[],
                 'js':[],
+                'img': [],
+                'json': [s.join(['rsrc','api','context.json']),
+                         s.join(['rsrc','api','common.json']),
+                         s.join(['rsrc','api','terms.json'])],
                 'xml':[s.join(['rsrc', 'resources.xml'])]
         }
         got = manager.run(['all', 'makeresources'])
@@ -930,8 +817,8 @@ Available modules:
             manager.run(["all", "runserver"])
             self.assertTrue(m2.called)
             self.assertTrue(m.serve_forever.called)
-        
-        
+
+
 
 import doctest
 from ferenda import manager
